@@ -269,6 +269,8 @@ def get_filtration(
         parsing_data = parser.parse(request.query_params)
         if default_model is not None:
             parsing_data = parsing_data.set_default_model(default_model)
+            if "." not in order_by:
+                order_by = f"{default_model}.{order_by}"
 
         _kwargs: dict[str, Any] = dict(to_filter=parsing_data, sort_by=sort_by)
         if page_number is not None:
